Summary: A collection of SNMP protocol tools and libraries.
Name: net-snmp
Version: 5.3.0.1 
Release: 2tr
License: BSD
Group: Trustix Official
URL: http://net-snmp.sourceforge.net/
Source0: http://nchc.dl.sourceforge.net/sourceforge/net-snmp/%{name}-%{version}.tar.gz
Source1: net-snmpd.init
Source2: net-snmptrapd.init
Source3: net-snmp.conf
Source4: net-snmp-5.2.1-perlreqexclude.sh
Prereq: /sbin/chkconfig /sbin/restart_maybe
BuildRequires: openssl-devel, bzip2-devel, beecrypt-devel, elfutils-devel, libselinux-devel
BuildPrereq: perl, coreutils, grep, sed, findutils
BuildRoot: %{_tmppath}/%{name}-root

# Default include header location should be /usr/include/net-snmp
%{expand: %%define _includedir %{_includedir}/%{name}}
# Auto-generated perl.req which need to be excluded
%define __perl_requires %{SOURCE4}

%description
SNMP (Simple Network Management Protocol) is a protocol used for
network management. The NET-SNMP project includes various SNMP tools:
an extensible agent, an SNMP library, tools for requesting or setting
information from SNMP agents, tools for generating and handling SNMP
traps, a version of the netstat command which uses SNMP, and a Tk/Perl
mib browser. This package contains the snmpd and snmptrapd daemons,
documentation, etc.

You will probably also want to install the net-snmp-utils package,
which contains NET-SNMP utilities.

%package utils
Group: Trustix Official
Summary: Network management utilities using SNMP, from the NET-SNMP project.
Requires: %{name} = %{version}

%description utils
The net-snmp-utils package contains various utilities for use with the
NET-SNMP network management project.

Install this package if you need utilities for managing your network
using the SNMP protocol. You will also need to install the net-snmp
package.

%package devel
Group: Trustix Official
Summary: The development environment for the NET-SNMP project.
Requires: %{name} = %{version}
BuildPrereq: elfutils-devel

%description devel
The net-snmp-devel package contains the development libraries and
header files for use with the NET-SNMP project's network management
tools.

Install the net-snmp-devel package if you would like to develop
applications for use with the NET-SNMP project's network management
tools. You'll also need to have the net-snmp and net-snmp-utils
packages installed.

%package perl
Group: Trustix Official
Summary: The perl NET-SNMP module and the mib2c tool.
Requires: %{name} = %{version}, perl >= 5
BuildRequires: perl >= 5
Provides: Perl(Net::SNMP)

%description perl
The net-snmp-perl package contains the perl files to use SNMP from within
Perl.

Install the net-snmp-perl package, if you want to use mib2c or SNMP with perl.

%package libs
Group: Trustix Official
Summary: The NET-SNMP runtime libraries.

%description libs
The net-snmp-libs package contains the runtime libraries for shared binaries
and applications.

%prep
%setup -q

# Do this patch with a perl hack...
perl -pi -e "s|'\\\$install_libdir'|'%{_libdir}'|" ltmain.sh

%build
%configure \
	--enable-static --enable-shared			\
	--enable-silent-libtool				\
	--with-cflags="$RPM_OPT_FLAGS"			\
	--with-logfile="/var/log/snmpd.log"		\
	--with-persistent-directory="/var/net-snmp"	\
	--with-mib-modules="host agentx smux misc/ipfwacc" \
	--with-libwrap=%{_libdir}			\
	--sysconfdir=%{_sysconfdir}			\
	--enable-ipv6					\
	--with-openssl					\
	--enable-ucd-snmp-compatibility			\
	--with-pic					\
	--with-sys-contact="root@localhost" <<EOF


EOF

make

pushd perl
# Use just built libs for perl module building, not the system libs.
perl Makefile.PL -NET-SNMP-IN-SOURCE=true PREFIX=$RPM_BUILD_ROOT/usr INSTALLDIRS=vendor
make
popd

%install
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / ] && rm -rf $RPM_BUILD_ROOT
%makeinstall  ucdincludedir=$RPM_BUILD_ROOT/usr/include/ucd-snmp


install -d $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/snmpd

install -d $RPM_BUILD_ROOT%{_sysconfdir}/snmp
install -m 755 %SOURCE3 $RPM_BUILD_ROOT%{_sysconfdir}/snmp/snmpd.conf

install -d $RPM_BUILD_ROOT%{_initdir}
install -m 755 %SOURCE1 $RPM_BUILD_ROOT%{_initdir}/snmpd
install -m 755 %SOURCE2 $RPM_BUILD_ROOT%{_initdir}/snmptrapd

# symlink to place NET::SNMP
install -d 755 $RPM_BUILD_ROOT%perl_vendorarch/Net
pushd $RPM_BUILD_ROOT%perl_vendorarch/Net
ln -sf ../SNMP.pm SNMP.pm
popd

# copy missing mib2c.conf files
cp local/mib2c.*.conf $RPM_BUILD_ROOT%{_datadir}/snmp

pushd perl
make install_vendor
eval $(perl '-V:installvendorarch')
popd

# remove docs that do not apply to Linux
for file in "README.aix README.hpux11 README.osX README.Panasonic_AM3X.txt README.solaris README.win32"
do rm $file
done

%pre
# Add user and group
if [ -z "`getent group snmpd`" ]; then
        /usr/sbin/groupadd -g 263 snmpd
fi
if [ -z "`getent passwd snmpd`" ]; then
        /usr/sbin/useradd -d /dev/null -s /no/shell \
        -g snmpd -u 263  snmpd
fi

%post
/sbin/chkconfig --add snmpd 
/sbin/restart_maybe snmpd
/sbin/chkconfig --add snmptrapd
/sbin/restart_maybe snmptrapd

%preun
if [ $1 = 0 ]; then
   service snmpd stop >/dev/null 2>&1
   /sbin/chkconfig --del snmpd
   service snmptrapd stop >/dev/null 2>&1
   /sbin/chkconfig --del snmptrapd
fi

%postun
# Remove user and group
if [ "$1" = "0" ]; then
        if [ -n "`getent passwd snmpd`" ]; then
                /usr/sbin/userdel snmpd
        fi
        if [ -n "`getent group snmpd`" ]; then
                /usr/sbin/groupdel snmpd
        fi
fi

%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig

%clean
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / ] && rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root,0755)
%doc	AGENT.txt COPYING ChangeLog EXAMPLE.conf FAQ NEWS PORTING README* TODO
%doc	local/passtest local/README.mib2c local/ipf-mod.pl
%dir	%{_sysconfdir}/snmp
%config(noreplace,missingok) %{_sysconfdir}/snmp/snmpd.conf
%config(noreplace) %{_initdir}/snmpd
%config(noreplace) %{_initdir}/snmptrapd
%config(noreplace) %{_sysconfdir}/logrotate.d/snmpd
%{_datadir}/snmp
%{_sbindir}/*
%{_mandir}/man[58]/*

%files utils
%defattr(-,root,root,0755)
%{_bindir}/fixproc
%{_bindir}/ipf-mod.pl
%{_bindir}/encode_keychange
%{_bindir}/snmp*
%{_bindir}/traptoemail
%{_bindir}/mib2c-update
%{_mandir}/man1/snmp*.1*

%files devel
%defattr(-,root,root,0755)
%{_libdir}/lib*.so
%{_includedir}/*
%{_prefix}/include/ucd-snmp/*
%{_mandir}/man3/
%{_bindir}/net-snmp-config

%files perl 
%defattr(-,root,root,0755)
%{_bindir}/mib2c
%perl_vendorarch/auto/
%perl_vendorarch/NetSNMP/
%perl_vendorarch/Bundle/
%perl_vendorarch/SNMP.pm
%perl_vendorarch/Net/SNMP.pm
%exclude %{_bindir}/tkmib
%exclude %{perl_archlib}/perllocal.pod
%{_mandir}/man1/
%{_mandir}/man3/

%files libs
%defattr(-,root,root,0755)
%{_libdir}/lib*.so.*
%{_libdir}/*.a
%{_libdir}/*.la

%changelog
* Mon Feb 26 2007 Nived Gopalan <nived at trustix dot org>
- Rebuilt

* Thu Jan 19 2006 Ajith Thampi <ajith at trustix dot org> 5.3.0.1-1tr
- New Upstream
		
* Fri Jan 06 2006 Ajith Thampi <ajith at trustix dot org> 5.3-1tr
- New Upstream
		
* Wed Oct 19 2005 Ajith Thampi <ajith at comodo dot com> 5.2.1.2-3tr
- Add symlink to place /Net/SNMP.pm
		
* Thu Jul 14 2005 Hasher Jamaludeen <hasher at comodo dot com> 5.2.1.2-2tr
- Made changes to the init scripts. Bug #1083.

* Thu Jul 07 2005 Bipin S <bipin at comodo dot com>5.2.1.2-1tr
- Fixed a denial of service vulnerability when stream sockets have
  been configured for use (E.G., TCP but not UDP). Bug#1038

* Mon Jun 06 2005 Ajith Thampi <ajith at comodo dot com> 5.2.1-6tr
- Rebuilt on perl-5.8.7
			
* Tue May 24 2005 Syed Shabir Zakiullah <syedshabir at comodo dot com> 5.2.1-4tr
- Security Fix: Net-snmp fixproc Insecure Temporary File Creation
- The vulnerability is caused due to fixproc creating temporary files
  insecurely. This can be exploited via symlink attacks to create or
  overwrite arbitrary files on the system with the privileges of the
  user running fixproc.

* Wed Apr 20 2005 Ajith Thampi <ajith at comodo dot com> 5.2.1-3tr
- merged changes from community-2.2 contribs

* Fri Apr 08 2005 Ajith Thampi <ajith at comodo dot com> 5.2.1-2tr
- Added snmp into the include to fix other dependencies

* Wed Apr 06 2005 Ajith Thampi <ajith at comodo dot com> 5.2.1-1tr
- Initial spec for tsl-3.0
